@@ -4,6 +4,7 @@ import jax.numpy as jnp
 from evofr.models.model_spec import ModelSpec
 from .basis_functions import BasisFunction, Spline
 from .model_factories import _renewal_model_factory
+from .latent_infections import _latent_renewal_model_factory
 
 
 class RenewalModel(ModelSpec):
@@ -19,12 +20,14 @@ class RenewalModel(ModelSpec):
         SLik=None,
         v_names: Optional[List[str]] = None,
         basis_fn: Optional[BasisFunction] = None,
+        latent: Optional[bool] = False,
     ):
         self.g_rev = jnp.flip(g, axis=-1)
         self.delays = delays
         self.seed_L = seed_L
         self.forecast_L = forecast_L
         self.v_names = v_names
+        self.latent = latent
 
         # Making basis expansion for Rt
         self.k = k if k else 10
@@ -39,7 +42,12 @@ class RenewalModel(ModelSpec):
         self.make_model()
 
     def make_model(self):
-        self.model_fn = _renewal_model_factory(
+        model_fn = (
+            _renewal_model_factory
+            if not self.latent
+            else _latent_renewal_model_factory
+        )
+        self.model_fn = model_fn(
             self.g_rev,
             self.delays,
             self.seed_L,
